function scores = calc_IQA(input_dir,original_dir,no_ref_measure,shave_width)

%% Reading original images
file_list = dir(original_dir); file_list(1:2,:) = [];
im_num = size(file_list,1);

original_images = cell(im_num,1);
for ii=1:im_num
    org_im = imread(fullfile(file_list(ii).folder,file_list(ii).name));
    org_im = rgb2ycbcr(org_im); org_im = org_im(:,:,1);
    original_images{ii} = org_im(1+shave_width:end-shave_width,...
        1+shave_width:end-shave_width);
end

%% Loading models and adding paths
addpath(genpath(fullfile(pwd,'IQA_algs')));

% NIQE model and defualt parameters
if strcmp(no_ref_measure,'NIQE');
    load(fullfile(pwd,'IQA_algs','niqe_release','modelparameters.mat'));
    blocksizerow    = 96;
    blocksizecol    = 96;
    blockrowoverlap = 0;
    blockcoloverlap = 0;
end

%% Calculating IQA scores

scores = struct('noRef',zeros(im_num,1),'MSE',zeros(im_num,1),...
    'SSIM',zeros(im_num,1),'MS_SSIM',zeros(im_num,1),...
    'IFC',zeros(im_num,1),'VIF',zeros(im_num,1));
base_dir = pwd;

for ii=1:im_num
    image = imread(fullfile(input_dir,file_list(ii,:).name));
    image = rgb2ycbcr(image); image = image(:,:,1);
    image = image(1+shave_width:end-shave_width,...
        1+shave_width:end-shave_width);
    
    scores.MSE(ii) = immse(image,original_images{ii});
    scores.SSIM(ii) = ssim_index(image, original_images{ii});
    scores.MS_SSIM(ii) = ssim_mscale_new(image, original_images{ii});
    scores.IFC(ii) = ifcvec(double(original_images{ii}), double(image));
    scores.VIF(ii) = vifvec(double(original_images{ii}), double(image));
    
    switch no_ref_measure
        case 'Ma'
            scores.noRef(ii) = quality_predict(image);
        case 'BRISQUE'
            cd('IQA_algs\brisque_release'); scores.noRef(ii) = ...
                brisquescore(image); cd(base_dir);
        case 'NIQE'
            cd('IQA_algs\niqe_release'); scores.noRef(ii) = ...
                computequality(image,blocksizerow,blocksizecol,...
                blockrowoverlap,blockcoloverlap, mu_prisparam,...
                cov_prisparam); cd(base_dir);
    end
end

end