function plot_PD_plane_set(scores_all,no_ref_measure)

algs = fieldnames(scores_all);
alg_num = length(algs);

full_ref_measures = {'MSE','SSIM','MS_SSIM','IFC','VIF'};
figure('units','normalized','outerposition',[0 0 1 1]);

for ii=1:5
    %% Extracting IQA scores for 16 SR algorithms
    data = struct('name',strings(alg_num,1),'X',zeros(alg_num,1),...
        'Y',zeros(alg_num,1));
    for jj=1:alg_num
        data.name(jj) = scores_all.(algs{jj}).name;
        data.X(jj) = mean(scores_all.(algs{jj}).(full_ref_measures{ii}));
        if strcmp(full_ref_measures{ii},'MSE')
            data.X(jj) = sqrt(data.X(jj));
        end
        data.Y(jj) = mean(scores_all.(algs{jj}).noRef);
    end
    
    %% Plotting
    subplot(2,3,ii);
    scatter(data.X,data.Y,80,hsv(alg_num),'filled');
    xlabel(full_ref_measures{ii}); ylabel(no_ref_measure); 
    
    if ~strcmp(full_ref_measures{ii},'MSE')
        set(gca,'xdir','reverse');
    else
        xlabel('RMSE');
    end
    if strcmp(no_ref_measure,'Ma')
        set(gca,'ydir','reverse');
        ylabel('Ma et al.');
    end
    if strcmp(full_ref_measures{ii},'MS_SSIM')
        xlabel('MS-SSIM');
    end
    
    % Adding alg names to plots
    x_interval = max(data.X)-min(data.X);
    for jj=1:alg_num
        txt = char(data.name(jj));
        direction = strcmp(full_ref_measures{ii},'MSE')*2-1;
        text(data.X(jj)+direction*x_interval/50,data.Y(jj),txt,'fontsize',10,'interpreter','latex');
    end
    
end

end